Crate scotch_guest_macros

Crate scotch_guest_macros 

Attribute Macros

guest_function
Macro used to annotate guest functions that should be exposed to the host.
host_functions
Macro used to annotate extern blocks that contain plugin imports.